"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Imports: Dependencies
const React = __importStar(require("react"));
const react_native_1 = require("react-native");
// import DateTimePicker from '@react-native-community/datetimepicker';
const react_native_modal_1 = __importDefault(require("react-native-modal"));
const moment_1 = __importDefault(require("moment"));
const Ionicons_1 = __importDefault(require("react-native-vector-icons/Ionicons"));
Ionicons_1.default.loadFont();
// Screen Dimensions
const { height, width } = react_native_1.Dimensions.get('window');
// Component: Date Range Picker
exports.DateRangePicker = (props) => {
    // React Hooks: State
    const [fromDateModalVisible, toggleFromDate] = React.useState(false);
    const [toDateModalVisible, toggleToDate] = React.useState(false);
    const [fromDate, setFromDate] = React.useState(new Date());
    const [toDate, setToDate] = React.useState(new Date());
    // Toggle From Date Modal
    const toggleFromDateModal = async (props) => {
        try {
            // Check Platform (iOS)
            if (react_native_1.Platform.OS === 'ios') {
                // React Hook: Toggle Modal
                toggleFromDate((fromDateModalVisible) => !fromDateModalVisible);
            }
            // Check Platform (Android)
            if (react_native_1.Platform.OS === 'android') {
                const { action, year, month, day } = await react_native_1.DatePickerAndroid.open({
                    date: fromDate,
                    mode: props.mode,
                });
                // Action: Date Set
                if (action === react_native_1.DatePickerAndroid.dateSetAction
                    && year !== undefined
                    && month !== undefined
                    && day !== undefined) {
                    // New Date
                    let newDate = new Date(year, month, day);
                    // Select From Date
                    selectFromDate(newDate);
                }
                // Action: Dismissed
                if (action === react_native_1.DatePickerAndroid.dismissedAction) {
                    // Do Nothing
                }
            }
        }
        catch (error) {
            console.log(error);
        }
    };
    // Toggle To Date Modal
    const toggleToDateModal = async (props) => {
        try {
            // Check Platform (iOS)
            if (react_native_1.Platform.OS === 'ios') {
                // React Hook: Toggle Modal
                toggleToDate((toDateModalVisible) => !toDateModalVisible);
            }
            // Check Platform (Android)
            if (react_native_1.Platform.OS === 'android') {
                const { action, year, month, day } = await react_native_1.DatePickerAndroid.open({
                    date: toDate,
                    mode: props.mode,
                });
                // Action: Date Set
                if (action === react_native_1.DatePickerAndroid.dateSetAction
                    && year !== undefined
                    && month !== undefined
                    && day !== undefined) {
                    // New Date
                    let newDate = new Date(year, month, day);
                    // Select To Date
                    selectToDate(newDate);
                }
                // Action: Dismissed
                if (action === react_native_1.DatePickerAndroid.dismissedAction) {
                    // Do Nothing
                }
            }
        }
        catch (error) {
            console.log(error);
        }
    };
    // Select From Date
    const selectFromDate = (date) => {
        try {
            // React Hook: Set From Date
            setFromDate(date);
            // React Props: onFromValueChange
            props.onFromValueChange(date);
        }
        catch (error) {
            console.log(error);
        }
    };
    // Select To Date
    const selectToDate = (date) => {
        try {
            // React Hook: Set To Date
            setToDate(date);
            // React Props: onToValueChange
            props.onToValueChange(date);
        }
        catch (error) {
            console.log(error);
        }
    };
    // Render From Date Picker
    const renderFromDatePicker = () => {
        try {
            return (<react_native_1.DatePickerIOS mode="date" date={fromDate} onDateChange={() => selectFromDate(fromDate)}/>);
        }
        catch (error) {
            console.log(error);
        }
    };
    // Render To Date Picker
    const renderToDatePicker = () => {
        try {
            return (<react_native_1.DatePickerIOS mode="date" date={toDate} onDateChange={() => selectToDate(toDate)}/>);
        }
        catch (error) {
            console.log(error);
        }
    };
    return (<react_native_1.View style={styles.container}>
      <react_native_1.View style={styles.titleContainer}>
        <react_native_1.Text style={styles.titleText}>{props.title}</react_native_1.Text>
      </react_native_1.View>

      <react_native_1.View style={styles.toFromDateContainer}>
        <react_native_1.TouchableOpacity onPress={() => toggleFromDateModal(props)} style={styles.dateInfoContainer}>
          <react_native_1.Text style={styles.dateText}>From</react_native_1.Text>
          <react_native_1.Text style={styles.text}>{moment_1.default(fromDate).format('MMM Do, YYYY')}</react_native_1.Text>
        </react_native_1.TouchableOpacity>

        <react_native_modal_1.default isVisible={fromDateModalVisible} style={styles.modal}>
          <react_native_1.View style={styles.modalContainer}>
            <react_native_1.View style={styles.pickerHeaderContainer}>
              <react_native_1.TouchableOpacity onPress={() => toggleFromDateModal(props)}>
                <react_native_1.Text style={styles.doneText}>Done</react_native_1.Text>
              </react_native_1.TouchableOpacity>
            </react_native_1.View>

            <react_native_1.View style={styles.pickerContainer}>
              {renderFromDatePicker()}
            </react_native_1.View>
          </react_native_1.View>
        </react_native_modal_1.default>
      </react_native_1.View>

      <react_native_1.View style={styles.divider}></react_native_1.View>

      <react_native_1.View style={styles.toFromDateContainer}>
        <react_native_1.TouchableOpacity onPress={() => toggleToDateModal(props)} style={styles.dateInfoContainer}>
          <react_native_1.Text style={styles.dateText}>To</react_native_1.Text>
          <react_native_1.Text style={styles.text}>{moment_1.default(toDate).format('MMM Do, YYYY')}</react_native_1.Text>
        </react_native_1.TouchableOpacity>

        <react_native_modal_1.default isVisible={toDateModalVisible} style={styles.modal}>
          <react_native_1.View style={styles.modalContainer}>
            <react_native_1.View style={styles.pickerHeaderContainer}>
              <react_native_1.TouchableOpacity onPress={() => toggleToDateModal(props)}>
                <react_native_1.Text style={styles.doneText}>Done</react_native_1.Text>
              </react_native_1.TouchableOpacity>
            </react_native_1.View>

            <react_native_1.View style={styles.pickerContainer}>
              {renderToDatePicker()}
            </react_native_1.View>
          </react_native_1.View>
        </react_native_modal_1.default>
      </react_native_1.View>
    </react_native_1.View>);
};
// Styles
const styles = react_native_1.StyleSheet.create({
    container: {
        display: 'flex',
        width: width - 32,
        marginRight: 16,
        marginLeft: 16,
        justifyContent: 'center',
    },
    titleContainer: {
        width: width,
        flexDirection: 'row',
        alignItems: 'center',
    },
    titleText: {
        alignSelf: 'flex-start',
        fontFamily: 'System',
        fontSize: 28,
        fontWeight: '700',
        color: '#000',
    },
    toFromDateContainer: {
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        height: 50,
    },
    dateInfoContainer: {
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        width: width - 32,
    },
    dateText: {
        fontFamily: 'System',
        fontSize: 17,
        fontWeight: '600',
        color: '#000',
    },
    text: {
        fontFamily: 'System',
        fontSize: 17,
        fontWeight: '400',
        color: '#007AFF',
    },
    arrowForward: {
        color: 'black',
        opacity: .3,
        marginRight: 7,
    },
    divider: {
        borderColor: '#7D7D7D',
        borderBottomWidth: react_native_1.StyleSheet.hairlineWidth,
        marginTop: 12,
        marginBottom: 12,
    },
    modal: {
        margin: 0,
    },
    modalContainer: {
        height: '100%',
        alignItems: 'center',
        justifyContent: 'flex-end',
    },
    pickerHeaderContainer: {
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'flex-end',
        alignItems: 'center',
        height: 40,
        width: width,
        backgroundColor: '#FAFAF8',
        borderColor: '#7D7D7D',
        borderBottomWidth: react_native_1.StyleSheet.hairlineWidth,
    },
    pickerContainer: {
        height: 220,
        width: width,
        // backgroundColor: '#CFD3D9',
        backgroundColor: 'white',
    },
    doneText: {
        fontFamily: 'System',
        color: '#007AFF',
        fontWeight: '600',
        fontSize: 17,
        marginRight: 16,
    },
});
